<?php
/*
Plugin Name: Color Palette Generator
Description: Generate color palette from an image.
Version: 1.0
Author: Farhan
*/


function color_palette_generator_shortcode($atts) {
    ob_start();
    ?>
    <style type="text/css">
        #colorPalette {
            display: flex;
            justify-content: space-between;
            margin-top: 20px;
            flex-wrap: wrap;
            align-content: flex-end;
        }

        .color-box {
            display: flex;
            flex-direction: column;
            align-items: center;
            width: 100px;
            height: 80px;
            margin-bottom: 10px;
            justify-content: space-around;
            color: white;
            font-family: 'Outfit';
            font-size: 14px;
            font-weight: bold;
            border-radius: 20px;
        }

        .color-name {
            font-size: 12px;
            text-align: center;
        }

        #defaultImage {
            display: none; /* Hide the default image */
        }
    </style>

    <?php
    // Check if WooCommerce is active
    if (class_exists('WooCommerce')) {
        // Check if we are on a single product page
        if (is_product()) {
            global $product;

            // Get the featured image URL
            $featured_image_url = wp_get_attachment_image_src(get_post_thumbnail_id($product->get_id()), 'full');
            
            // Output the image element with the featured image URL
            echo '<img id="defaultImage" src="' . esc_url($featured_image_url[0]) . '" alt="Product Image">';
        }
    }
    ?>

    <div id="colorPalette"></div>

    <script src="https://farhanrashid.com/wp-content/uploads/color-thief.js"></script>
    <script src="https://cdnjs.cloudflare.com/ajax/libs/tinycolor/1.6.0/tinycolor.min.js"></script>

    <script src="https://chir.ag/projects/ntc/ntc.js"></script> <!-- Replace with the actual path to ntc.js -->

    <script type="text/javascript">
        document.addEventListener('DOMContentLoaded', function () {
            const defaultImage = document.getElementById('defaultImage');
            const colorPaletteDiv = document.getElementById('colorPalette');

            // Display color palette for the default image on page load
            displayColorPalette(defaultImage.src);

            function displayColorPalette(image) {
                const colorThief = new ColorThief();

                if (typeof image === 'string') {
                    // If the input is a URL
                    const img = new Image();
                    img.crossOrigin = 'Anonymous'; // Enable cross-origin resource sharing
                    img.src = image;

                    img.onload = function () {
                        const colorPalette = colorThief.getPalette(img, 13);
                        renderColorPalette(colorPalette);
                    };
                } else {
                    // If the input is a File
                    const reader = new FileReader();

                    reader.onload = function (event) {
                        const img = new Image();
                        img.src = event.target.result;

                        img.onload = function () {
                            const colorPalette = colorThief.getPalette(img, 15);
                            renderColorPalette(colorPalette);
                        };
                    };

                    reader.readAsDataURL(image);
                }
            }

            function renderColorPalette(colorPalette) {
                colorPaletteDiv.innerHTML = '';
                colorPalette.forEach(color => {
                    const colorBox = document.createElement('div');
                    colorBox.style.backgroundColor = `rgb(${color[0]}, ${color[1]}, ${color[2]})`;
                    colorBox.classList.add('color-box');

                    const colorCode = document.createElement('div');
                    const hexCode = tinycolor(`rgb(${color[0]}, ${color[1]}, ${color[2]})`).toHexString();
                    colorCode.textContent = hexCode;
                    colorCode.classList.add('color-code');

                    const colorName = document.createElement('div');
                    const colorNameText = getColorName(hexCode);
                    colorName.textContent = colorNameText;
                    colorName.classList.add('color-name');

                    colorBox.appendChild(colorCode);
                    colorBox.appendChild(colorName);
                    colorPaletteDiv.appendChild(colorBox);
                });
            }

            function getColorName(hexCode) {
                const ntcResult = ntc.name(hexCode);
                return ntcResult[1] || 'Unknown';
            }
        });
    </script>

    <?php
    return ob_get_clean();
}

add_shortcode('color_palette_generator', 'color_palette_generator_shortcode');




?>
